==> mccoygroup_mcutils-1.5.0.tar.gz: mccoygroup_mcutils-1.5.0/McUtils/Data/TheRealMcCoy/ColorData.py <==
source = ["pokemon", "https://www.heavy.ai/blog/12-color-palettes-for-telling-better-stories-with-your-data"]
data = {
    "Palettes": {
        "default": [
            "#3F5679", "#E19C24", "#8FB032", "#EB6235", "#5A5077", "#834911", "#5D9EC7",
            "#FFBF00", "#A5609D", "#929600", "#E95536", "#6685D9", "#F89F13", "#BC5B80",
            "#47B66D"
        ],
        "pastel": [
            "#ffb55a", "#7eb0d5", "#b2e061", "#fd7f6f",
            "#bd7ebe", "#ffee65", "#beb9db", "#fdcce5", "#8bd3c7"
        ],
        "starters": [
            "#5a9ca4","#e63900","#ffd508","#526229","#62d5b4","#ac0031","#ffd57b","#73ac31",
            "#184a4a","#8b2900","#f6a400"
        ],
        "neon":["#0bb4ff", "#ffa300", "#50e991", "#e60049", "#e6d800", "#9b19f5", "#dc0ab4", "#b3d4ff", "#00bfa0"],
        "dark-rainbow":["#b30000", "#7c1158", "#4421af", "#1a53ff", "#0d88e6", "#00b7c7", "#5ad45a", "#8be04e", "#ebdc78"],
        "pikafree": [
            "#313152","#f6e652","#8383bd","#f6bd20","#6abdcd","#c52018","#bdbde6",
            "#de3131","#fff6a4","#41414a","#9c5200","#ff9cb4","#623108","#623139"
        ]
    },
    "Gradients": {
        "BlueToRed": [
            "#1984c5", "#22a7f0", "#63bff0", "#a7d5ed", "#e2e2e2",
            "#e1a692", "#de6e56", "#e14b31", "#c23728"
        ],
        "PinkTeal": [
            "#e27c7c", "#a86464", "#6d4b4b", "#503f3f", "#333333",
            "#3c4e4b", "#466964", "#599e94", "#6cd4c5"
        ],
        "WarioColors": [
            "#ffb400", "#d2980d", "#a57c1b", "#786028", "#363445",
            "#48446e", "#5e569b", "#776bcd", "#9080ff"
        ],
        "SeaFoam": [
            "#54bebe", "#76c8c8", "#98d1d1", "#badbdb", "#dedad2",
            "#e4bcad", "#df979e", "#d7658b", "#c80064"
        ]
    }
}

==> mccoygroup_mcutils-1.5.6.1.tar.gz: mccoygroup_mcutils-1.5.6.1/McUtils/Data/TheRealMcCoy/ColorData.py <==
source = ["pokemon", "https://www.heavy.ai/blog/12-color-palettes-for-telling-better-stories-with-your-data"]
data = {
    "Palettes": {
        "default": [
            '001C7F', '017517', '8C0900', '7600A1', 'B8860B', '006374',
            '#10278A', '#368827', '#A5151A', '#9015B5', '#E79E37', '#307487'
        ],
        "contrasting": [
            "#3F5679", "#E19C24", "#8FB032", "#EB6235", "#5A5077", "#834911", "#5D9EC7",
            "#FFBF00", "#A5609D", "#929600", "#E95536", "#6685D9", "#F89F13", "#BC5B80",
            "#47B66D"
        ],
        "pastel": [
            "#ffb55a", "#7eb0d5", "#b2e061", "#fd7f6f",
            "#bd7ebe", "#ffee65", "#beb9db", "#fdcce5", "#8bd3c7"
        ],
        "starters": [
            "#5a9ca4","#e63900","#ffd508","#526229","#62d5b4","#ac0031","#ffd57b","#73ac31",
            "#184a4a","#8b2900","#f6a400"
        ],
        "neon":["#0bb4ff", "#ffa300", "#50e991", "#e60049", "#e6d800", "#9b19f5", "#dc0ab4", "#b3d4ff", "#00bfa0"],
        "dark-rainbow":["#b30000", "#7c1158", "#4421af", "#1a53ff", "#0d88e6", "#00b7c7", "#5ad45a", "#8be04e", "#ebdc78"],
        "pikafree": [
            "#313152","#f6e652","#8383bd","#f6bd20","#6abdcd","#c52018","#bdbde6",
            "#de3131","#fff6a4","#41414a","#9c5200","#ff9cb4","#623108","#623139"
        ]
    },
    "Gradients": {
        "BlueToRed": [
            "#1984c5", "#22a7f0", "#63bff0", "#a7d5ed", "#e2e2e2",
            "#e1a692", "#de6e56", "#e14b31", "#c23728"
        ],
        "PinkTeal": [
            "#e27c7c", "#a86464", "#6d4b4b", "#503f3f", "#333333",
            "#3c4e4b", "#466964", "#599e94", "#6cd4c5"
        ],
        "WarioColors": [
            "#ffb400", "#d2980d", "#a57c1b", "#786028", "#363445",
            "#48446e", "#5e569b", "#776bcd", "#9080ff"
        ],
        "SeaFoam": [
            "#54bebe", "#76c8c8", "#98d1d1", "#badbdb", "#dedad2",
            "#e4bcad", "#df979e", "#d7658b", "#c80064"
        ]
    }
}
